==> proc-10.1.59.tar.gz: proc/src/Form/ProcDecryptForm.php <==
<?php

namespace Drupal\proc\Form;

use Drupal\Component\Utility\Crypt;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Path\CurrentPathStack;
use Drupal\Core\Url;
use Drupal\proc\ProcInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;

/**
 * Decrypt content.
 */
class ProcDecryptForm extends FormBase {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The module handler service.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected ModuleHandlerInterface $moduleHandler;

  /**
   * The current path.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected $currentPath;

  /**
   * ProcEncryptForm form.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   * @param \Drupal\Core\Path\CurrentPathStack $current_path
   *   The current path.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    ModuleHandlerInterface $module_handler,
    CurrentPathStack $current_path,
  ) {
    $this->configFactory = $config_factory;
    $this->moduleHandler = $module_handler;
    $this->currentPath = $current_path;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('config.factory'),
      $container->get('module_handler'),
      $container->get('path.current')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'proc_decrypt_form';
  }

  /**
   * Dynamic title for Decrypt form.
   */
  public function getTitle() {
    $title = $this->t('Download and decrypt');

    if (!$this->isFileInputMode()) {
      $title = $this->t('Decrypt');
    }

    return $title;
  }

  /**
   * Build the decryption form.
   *
   * @param array $form
   *   Default form array structure.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Object containing current form state.
   *
   * @return array
   *   The render array defining the elements of the form.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->configFactory->get('proc.settings');
    $allow_password_caching = $config->get('proc-allow-password-cache-fields');
    $query_params = $this->getRequest()->query->all();
    $cache_password = $query_params['cache-password'] ?? NULL;

    $form['password'] = [
      '#type' => 'password',
      '#title' => $this->t('Protected Content Password'),
      '#description' => $this->t('You must type in the password used on registering your Protected Content Key.'),
    ];

    if ($allow_password_caching && in_array($cache_password, ['1', '2'])) {
      $form['cache_password'] = [
        '#type' => ($cache_password == '2') ? 'hidden' : 'checkbox',
        '#title' => 'Cache password',
        '#attributes' => [
          'onclick' => 'this.value = this.checked ? "1" : "0";',
        ],
      ];
    }

    $decryption_link_classes = [
      'button--primary',
      'button',
    ];

    $this->moduleHandler->alter('decryption_link_classes', $decryption_link_classes, $form_state);

    $fragment = Crypt::hashBase64(Crypt::randomBytesBase64(32));

    $input_mode = $query_params['field-input-mode'] ?? NULL;
    $link_text = ($input_mode !== ProcInterface::INPUT_MODE_FILE) ? $this->t('Decrypt') : FALSE;

    $form['decrypt'] = [
      '#type' => 'link',
      '#title' => $link_text ?: $this->t('Download and decrypt'),
      '#url' => Url::fromUserInput('#' . $fragment),
      '#attributes' => [
        'id' => 'decryption-link',
        'class' => $decryption_link_classes ?? [],
      ],
    ];

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $link_text ?: $this->t('Download and decrypt'),
      '#attributes' => [
        'id' => 'decryption-btn',
        'style' => 'display: none',
        'disabled' => TRUE,
      ],
    ];

    $current_path = $this->currentPath->getPath();
    $path_array = explode('/', $current_path);
    $cipher_ids_csv = $path_array[2];
    $cids = _proc_get_csv_argument($cipher_ids_csv);
    $ciphers_data = _proc_common_get_ciphers($cids, FALSE);

    $query_params = $this->getRequest()->query->all();

    if (empty($ciphers_data['pubkey'])) {
      ProcDecryptForm::denyAccess();
    }

    $common_data = _proc_common_get_decryption_form_data($ciphers_data['privkey']);

    $ciphers_changed = $files_names = $files_sizes = $sources_input_mode = $sources_signed = [];

    foreach ($ciphers_data['ciphers'] as $cipher_id_data) {
      $ciphers_changed[] = $cipher_id_data['changed'] ?? 0;
      $files_names[] = $cipher_id_data['source_file_name'] ?? '';
      $files_sizes[] = $cipher_id_data['source_file_size'] ?? 0;
      $sources_input_mode[] = $cipher_id_data['source_input_mode'] ?? 0;
      $sources_signed[] = 0;
    }

    $form['#attached'] = [
      'library' => [
        0 => 'proc/openpgpjs',
        1 => 'proc/proc-decrypt',
      ],
      'drupalSettings' => [
        'proc' => [
          'proc_labels' => _proc_js_labels(),
          'proc_pass' => $common_data['proc_pass'],
          'proc_keyring_type' => $ciphers_data['keyring_type'],
          'proc_privkey' => $ciphers_data['privkey'],
          'proc_ids' => array_keys($ciphers_data['ciphers']),
          'procs_changed' => $ciphers_changed,
          'proc_sources_file_names' => $files_names,
          'proc_sources_file_sizes' => $files_sizes,
          'proc_sources_input_modes' => $sources_input_mode,
          'proc_sources_signed' => $sources_signed,
          'proc_skip_size_mismatch' => 'TRUE',
          'base_path' => base_path(),
          'proc_signed' => $sources_signed,
          'proc_decryption_mode' => $query_params['field-decryption-mode'] ?? '0',
          'proc_field_name' => $query_params['proc_field_name'] ?? '',
          'proc_parent_id' => $query_params['proc_parent_id'] ?? '',
          'proc_in_mode' => $query_params['field-input-mode'] ?? '',
          'proc_cache_password_mode' => $query_params['cache-password'] ?? '0',
          'proc_decryption_trigger_fields' => $query_params['trigger-fields'] ?? '0',
        ],
      ],
    ];

    return $form;
  }

  /**
   * Implements form validation.
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * Implements a form submit handler.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {}

  /**
   * Deny access.
   */
  public function denyAccess() {
    throw new AccessDeniedHttpException();
  }

  /**
   * Validade if Proc field input mode sets a file field.
   */
  private function isFileInputMode() {
    $query_string = $this->getRequest()->query->all();
    if (isset($query_string['field-input-mode'])) {
      $input_mode = $query_string['field-input-mode'];
    }
    if (!isset($input_mode)) {
      return FALSE;
    }

    return ((int) $input_mode === ProcInterface::INPUT_MODE_FILE);
  }

}

==> proc-10.1.68.tar.gz: proc/src/Form/ProcDecryptForm.php <==
<?php

namespace Drupal\proc\Form;

use Drupal\Component\Utility\Crypt;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Path\CurrentPathStack;
use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Url;
use Drupal\proc\ProcInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpKernel\Exception\AccessDeniedHttpException;

/**
 * Decrypt content.
 *
 * @SuppressWarnings(PHPMD.StaticAccess)
 */
class ProcDecryptForm extends FormBase {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The module handler service.
   *
   * @var \Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected ModuleHandlerInterface $moduleHandler;

  /**
   * The current path.
   *
   * @var \Drupal\Core\Path\CurrentPathStack
   */
  protected CurrentPathStack $currentPath;

  /**
   * ProcEncryptForm form.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The config factory.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   * @param \Drupal\Core\Path\CurrentPathStack $current_path
   *   The current path.
   */
  public function __construct(
    ConfigFactoryInterface $config_factory,
    ModuleHandlerInterface $module_handler,
    CurrentPathStack $current_path,
  ) {
    $this->configFactory = $config_factory;
    $this->moduleHandler = $module_handler;
    $this->currentPath = $current_path;
  }

  /**
   * {@inheritdoc}
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The Drupal service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('config.factory'),
      $container->get('module_handler'),
      $container->get('path.current')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'proc_decrypt_form';
  }

  /**
   * Dynamic title for Decrypt form.
   */
  public function getTitle(): TranslatableMarkup {
    $title = $this->t('Download and decrypt');

    if (!$this->isFileInputMode()) {
      $title = $this->t('Decrypt');
    }

    return $title;
  }

  /**
   * Build the decryption form.
   *
   * @param array $form
   *   Default form array structure.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   Object containing current form state.
   *
   * @return array
   *   The render array defining the elements of the form.
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->configFactory->get('proc.settings');
    $pass_caching = $config->get('proc-allow-password-cache-fields');
    $query_params = $this->getRequest()->query->all();
    $cache_password = $query_params['cache-password'] ?? NULL;
    $form['password'] = [
      '#type' => 'password',
      '#title' => $this->t('Protected Content Password'),
      '#description' => $this->t('You must type in the password used on registering your Protected Content Key.'),
      '#attributes' => [
        'autocomplete' => 'new-password',
      ],
    ];
    if ($pass_caching && in_array($cache_password, ['1', '2'])) {
      $form['cache_password'] = [
        '#type' => ($cache_password == '2') ? 'hidden' : 'checkbox',
        '#title' => 'Cache password',
        '#attributes' => [
          'onclick' => 'this.value = this.checked ? "1" : "0";',
        ],
      ];
    }
    $dec_link_classes = [
      'button--primary',
      'button',
    ];
    $this->moduleHandler->alter('decryption_link_classes', $dec_link_classes, $form_state);
    $fragment = Crypt::hashBase64(Crypt::randomBytesBase64(32));
    $input_mode = $query_params['field-input-mode'] ?? NULL;
    $link_text = ($input_mode !== ProcInterface::INPUT_MODE_FILE) ? $this->t('Decrypt') : FALSE;
    $form['decrypt'] = [
      '#type' => 'link',
      '#title' => $link_text ?: $this->t('Download and decrypt'),
      '#url' => Url::fromUserInput('#' . $fragment),
      '#attributes' => [
        'id' => 'decryption-link',
        'class' => $dec_link_classes ?? [],
      ],
    ];
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $link_text ?: $this->t('Download and decrypt'),
      '#attributes' => [
        'id' => 'decryption-btn',
        'style' => 'display: none',
        'disabled' => TRUE,
      ],
    ];
    $current_path = $this->currentPath->getPath();
    $path_array = explode('/', $current_path);
    $cipher_ids_csv = $path_array[2];
    $cids = _proc_get_csv_argument($cipher_ids_csv);
    $ciphers_data = _proc_common_get_ciphers($cids, FALSE);
    $query_params = $this->getRequest()->query->all();
    if (empty($ciphers_data['pubkey'])) {
      ProcDecryptForm::denyAccess();
    }
    $common_data = _proc_common_get_decryption_form_data($ciphers_data['privkey']);
    $ciphers_changed = $files_names = $files_sizes = $sources_input_mode = $sources_signed = [];
    foreach ($ciphers_data['ciphers'] as $cipher_id_data) {
      $ciphers_changed[] = $cipher_id_data['changed'] ?? 0;
      $files_names[] = $cipher_id_data['source_file_name'] ?? '';
      $files_sizes[] = $cipher_id_data['source_file_size'] ?? 0;
      $sources_input_mode[] = $cipher_id_data['source_input_mode'] ?? 0;
      $sources_signed[] = 0;
    }
    $form['#attached'] = [
      'library' => [
        0 => 'proc/openpgpjs',
        1 => 'proc/proc-decrypt',
      ],
      'drupalSettings' => [
        'proc' => [
          'proc_labels' => _proc_js_labels(),
          'proc_pass' => $common_data['proc_pass'],
          'proc_keyring_type' => $ciphers_data['keyring_type'],
          'proc_privkey' => $ciphers_data['privkey'],
          'proc_ids' => array_keys($ciphers_data['ciphers']),
          'procs_changed' => $ciphers_changed,
          'proc_sources_file_names' => $files_names,
          'proc_sources_file_sizes' => $files_sizes,
          'proc_sources_input_modes' => $sources_input_mode,
          'proc_sources_signed' => $sources_signed,
          'proc_skip_size_mismatch' => 'TRUE',
          'base_path' => base_path(),
          'proc_signed' => $sources_signed,
          'proc_decryption_mode' => $query_params['field-decryption-mode'] ?? '0',
          'proc_field_name' => $query_params['proc_field_name'] ?? '',
          'proc_parent_id' => $query_params['proc_parent_id'] ?? '',
          'proc_in_mode' => $query_params['field-input-mode'] ?? '',
          'proc_cache_password_mode' => $query_params['cache-password'] ?? '0',
          'proc_decryption_trigger_fields' => $query_params['trigger-fields'] ?? '0',
        ],
      ],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {}

  /**
   * Deny access.
   */
  public function denyAccess() {
    throw new AccessDeniedHttpException();
  }

  /**
   * Validate if Proc field input mode sets a file field.
   */
  private function isFileInputMode(): bool {
    $query_string = $this->getRequest()->query->all();
    if (isset($query_string['field-input-mode'])) {
      $input_mode = $query_string['field-input-mode'];
    }
    if (!isset($input_mode)) {
      return FALSE;
    }

    return ((int) $input_mode === ProcInterface::INPUT_MODE_FILE);
  }

}
